man > ircII(1)

IRCII(1)                               General Commands Manual                              IRCII(1)

NAME
       ircII — interface to the Internet Relay Chat system

SYNOPSIS
       irc   [-abdFfqrSsTtv]   [-c   chan]   [-D   level]   [-e  protocol  level]  [-H  host[:port]]
           [-h host[:port]]  [-I  ircrcquick]  [-icb]  [-irc]  [-l  ircrc]  [-o  file]  [-P  portno]
           [-p portno] [-R host[:port]] [nickname [server list]] [--]

DESCRIPTION
       The ircII program is a full screen, termcap based interface to Internet Relay Chat.  It gives
       full access to all of the normal IRC functions, plus a variety of additional options.

OPTIONS
       The following options are supported:

       -a                  This  adds  the  normal  irc  server list to the command line list of irc
                           servers.

       -b                  Load the .ircrc file before connection to a server, not afterwards.

       -c chan             Automatically join channel chan.

       -d                  Start in non-full screen mode.  All input is taken  directly  from  stdin
                           and  all output goes to stdout without using any of the termcap(5) screen
                           control codes.

       -D level            Enable debugging of level.  This option is only  available  if  ircII  is
                           built with -DDEBUG.

       -e protocol level   For  protocol  protocol, set the default encryption (SSL) level to level.
                           Currently, only "IRC" is supported for the protocol and the  values  that
                           level  can  take  are "check", "nocheck", and "off".  Please also see the
                           description of the "server list" below.

       -F                  Don't use flow control (^S and ^Q)  to  stop  start  the  display.   This
                           switch is ignored if the -d switch is used.

       -f                  Use  flow  control (^S and ^Q) to stop/start the display.  Normally these
                           are both bound to other functions within ircII.  This switch  is  ignored
                           if the -d switch is used.

       -H host[:port]      This  option  instructs  ircII to use the given host as the local address
                           for DCC, and works otherwise identically to the -h option.

       -h host[:port]      This option instructs ircII to use the given host as the  local  address.
                           Useful  only  on  multi-homed hosts.  If the optional port segment is in‐
                           cluded, ircII will attempt to bind to this local port as  well  as  local
                           host  address.   If  host is an IPv6 "number", it must be provided in the
                           common file ... [12:34:ab:cd] format.  This means for  an  IPv6  "number"
                           and port, it would be written [12:34:ab:cd]:6669.

       -icb                Use ICB connections by default.

       -irc                Use IRC connections by default.

       -l ircrc            Use ircrc Instead of the default ~/.ircrc.

       -o file             Set  the  debug  output  file  to file.  This option is only available if
                           ircII is built with -DDEBUG.

       -P portno           Set the ICB port number to portno (default: 7326, the standard ICB port).

       -p portno           Set the IRC port number to portno (default: 6667, the standard IRC port).
                           Only supply this if you connect to a server which uses a port other  than
                           6667.

       -q                  Start  up ircII quickly.  Don't load the IRCRC file, only the quick IRCRC
                           file set by the

       -I                  option.

       -R host[:port]      Set the default HTTP proxy host for server connections to host:port.

       -r                  Reverse the normal default foreground and background colours.

       -S                  Start up the ircio process to connect to the IRC server.

       -s                  Don't start up the ircio process to connect to the IRC server (default).

       -T                  Do use the termcap ti and te sequences when starting and exiting if  they
                           exist.

       -t                  Don't  use the termcap ti and te sequences when starting and exiting (de‐
                           fault).

       -v                  Print the version and release date of ircII and exit.

       --                  End all option processing.

       The remaining command line arguments are:

       •   nickname Set the nickname (overrides the environment variable IRCNICK; default: the user‐
           name).

       •   server list Set the list of servers with which ircII will try to  connect  upon  startup.
           This list is also used by the program's /server command.

       For IRC connections, the format is: host[:portno[:password[:nick]]]

       For ICB connections, the format is: ICB/host [:portno[:nick[:group[:mode]]]] with group being
       the  initial group and mode being the initial group mode.  See /HELP ICB for more information
       about ICB.

       If the host is in the format :servergroup:host.com then servergroup is taken to be the Server
       Group for this server entry.

       If the host is prefixed with SSLIRC/ or SSLIRCNOCHECK/ then an attempt will be made to initi‐
       ate an SSL/TLS connection for this host.  The SSLIRCNOCHECK/ form does not verify the  remote
       server's certificate, which may have security implications.  Please see SSL/TLS documentation
       for more information.

       If  the  host is prefixed with PROXY/host:port/ then this server will be connected via speci‐
       fied HTTP proxy server.  The NO_PROXY/ prefix will disable any global proxy setting for  this
       server.

DETAILED DESCRIPTION
   The Screen
       The screen is split into two parts, separated by an inverse-video status line (if supported).
       The upper (larger) part of the screen displays responses from the IRC server.  The lower part
       of the screen (a single line) accepts keyboard input.

       Some terminals do not support certain features required by ircII, in which case you receive a
       message  stating  this.  If this occurs, try changing the terminal type or run ircII with the
       -d option.

   IRC Commands
       Any line beginning with the slash character (‘/’) is regarded as an ircII command  (the  com‐
       mand  character  may  be  changed; type /help set cmdchar).  Any line not beginning with this
       character is treated as a message to be sent to the current channel.  To produce a listing of
       commands, type /help ?.  To receive information about the commands type /help <command>.

   The .ircrc File
       When ircII is executed, it checks the user's home directory for a .ircrc file, executing  the
       commands  in  the  file.  Commands in this file do not need to have a leading slash character
       (‘/’).  This allows predefinition of aliases and other features.

ENVIRONMENT
       It can be helpful to predefine certain variables in in the .cshrc, .profile, or .login file:

       IRCNICK       The user's ircII nickname.

       IRCNAME       The user's IRC realname (otherwise retrieved from /etc/passwd)

       IRCSERVER     The default IRC server(s) (see server option for details)

       IRCSERVERSFILE
                     The   file   containing   the    default    list    of    server(s),    usually
                     PREFIX/share/irc/ircII.servers.   This file should contain one server entry per
                     line.

       HOME          Overrides the default home path in /etc/passwd.

       TERM          The type of terminal in use.

FILES
       ~/.ircrc              default initialization file

       ~/.irc/               directory into which you can put your own ircII scripts, that can  then
                             be loaded with /load

       .../share/irc/        directory  containing  message-of-the-day,  master initialization, help
                             files, and ircII scripts

       .../share/irc/script/global
                             file loaded at the start of every ircII session.

       PREFIX/share/irc/ircII.servers
                             The initial list of servers if none are provided on the command line.

       PREFIX/share/irc/ircII.motd
                             Message of the day.  This file is displayed only once each time  it  is
                             changed.

EXAMPLES
             irc -c #users -p 5555
       Connect IRC to port number 5555 of the default host and enter on channel #users.
             irc Mermaid
       Use the nickname “Mermaid”.
             irc Mermaid server1:5000 server2::passwd server3
       Use the nickname “Mermaid” and the modified server list.
             irc piglet3 :ln:irc1.lamenet.org :ln:irc.us.lamenet.org
       Use   the   nickname   “piglet3”,  initially  connecting  to  irc.au.lamenet.org,  with  also
       irc.us.lamenet.org added to the server list, both having a server group name “ln”.
             irc oink ICB/www.icb.net
       Use the nick “oink” making an ICB connection to www.icb.net.
             irc -d
       Use dumb mode.
             irc -f
       Allow use of ^S/^Q to stop/start screen display.
             irc -e elisa
       Interface IRC with a program called “elisa”.

             setenv IRCNICK Mermaid
             setenv IRCNAME
             irc
       Set the username (if not specified elsewhere) to “Mermaid”.  The user's name  (when  provided
       inside parentheses in response to a WHOIS command) is set to “The one and only :)”.

THE HELP FILES
       All  of  the  ircII  commands are fully described in the help files package.  The best way to
       start here is with the /HELP ? command as this prints a listing of all available help files.

SIGNALS
       ircII handles the following signals

       SIGUSR1          Closes all DCC connections and EXEC'ed processes.

       SIGUSR2          Drops ircII back to the command line.

SEE ALSO
       irc(1), ircd(8)

AUTHORS
       Program written by Michael Sandrof <ms5n+@andrew.cmu.edu>.  Now being maintained  by  Matthew
       Green <mrg AT eterna.au> Names of contributors and contact address can be retrieved with the
       /info  command.   This manual page written by Darren Reed <avalon AT coombs.AU>, revised
       by R. P. C. Rodgers <rodgers AT maxwell.edu>,  by  the  lynX,  and  by  Matthew  Green
       <mrg AT eterna.au>.

BUGS
       Please notify the current developer of the software of any bugs in current versions.

Debian                                      June 6, 2017                                    IRCII(1)
ircII(1) □✕
NAME SYNOPSIS DESCRIPTION OPTIONS
-a This adds the normal irc server list to the command line list of irc -b Load the .ircrc file before connection to a server, not afterwards. -c chan Automatically join channel chan. -d Start in non-full screen mode. All input is taken directly from stdin -D level Enable debugging of level. This option is only available if ircII is -e protocol level For protocol protocol, set the default encryption (SSL) level to level. -F Don't use flow control (^S and ^Q) to stop start the display. This -f Use flow control (^S and ^Q) to stop/start the display. Normally these -H host[:port] This option instructs ircII to use the given host as the local address -h host[:port] This option instructs ircII to use the given host as the local address. -icb Use ICB connections by default. -irc Use IRC connections by default. -l ircrc Use ircrc Instead of the default ~/.ircrc. -o file Set the debug output file to file. This option is only available if -P portno Set the ICB port number to portno (default: 7326, the standard ICB port). -p portno Set the IRC port number to portno (default: 6667, the standard IRC port). -q Start up ircII quickly. Don't load the IRCRC file, only the quick IRCRC -I option. -R host[:port] Set the default HTTP proxy host for server connections to host:port. -r Reverse the normal default foreground and background colours. -S Start up the ircio process to connect to the IRC server. -s Don't start up the ircio process to connect to the IRC server (default). -T Do use the termcap ti and te sequences when starting and exiting if they -t Don't use the termcap ti and te sequences when starting and exiting (de‐ -v Print the version and release date of ircII and exit.
DETAILED DESCRIPTION
The Screen -d option. IRC Commands The .ircrc File
ENVIRONMENT FILES EXAMPLES THE HELP FILES SIGNALS SEE ALSO AUTHORS BUGS

Generated by phpman v4.12.11 · Markdown · JSON Author: Che Dong Under GNU General Public License
2026-10-21 00:06 @216.73.217.130
CrawledBy Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko; compatible; ClaudeBot/1.0; +claudebot@anthropic.com)
Valid XHTML 1.0 Transitional!Valid CSS!

^_top_^